@@ -2,11 +2,8 @@
 context("deferred http")
 
 test_that("GET", {
-
-  skip_if_offline()
-
   do <- async(function() {
-    http_get("https://eu.httpbin.org/get?q=42")$
+    http_get(http$url("/get", query = list(q = 42)))$
       then(function(x) rawToChar(x$content))$
       then(function(x) expect_match(x, "\"q\":[ ]*\"42\"", fixed = FALSE))
   })
@@ -14,22 +11,16 @@ test_that("GET", {
 })
 
 test_that("HEAD", {
-
-  skip_if_offline()
-
   do <- async(function() {
-    http_head("https://eu.httpbin.org")$
+    http_head(http$url("/"))$
       then(function(x) expect_equal(x$status_code, 200))
   })
   synchronise(do())
 })
 
 test_that("http_stop_for_status", {
-
-  skip_if_offline()
-
   do <- async(function() {
-    http_get("https://eu.httpbin.org/status/404")$
+    http_get(http$url("/status/404"))$
       then(http_stop_for_status)
   })
   expect_error(synchronise(do()), "404", class = "async_http_404")
