@@ -3,17 +3,17 @@ context("deferred")
 
 test_that("action in formula notation", {
   do <- function() {
-    dx1 <- deferred$new(~ resolve(TRUE))$
-      then(~ expect_true(.))
+    dx1 <- deferred$new(function(resolve) resolve(TRUE))$
+      then(function(.) expect_true(.))
 
-    dx2 <- deferred$new(~ stop("oops"))$
-      catch(error = ~ expect_match(conditionMessage(.), "oops"))
+    dx2 <- deferred$new(function(resolve) stop("oops"))$
+      catch(error = function(.) expect_match(conditionMessage(.), "oops"))
 
-    dx3 <- deferred$new(~ if (TRUE) resolve(TRUE) else stop("oops"))$
-      then(~ expect_true(.))
+    dx3 <- deferred$new(function(resolve) if (TRUE) resolve(TRUE) else stop("oops"))$
+      then(function(.) expect_true(.))
 
-    dx4 <- deferred$new(~ if (FALSE) resolve(TRUE) else stop("oops"))$
-      catch(error = ~ expect_match(conditionMessage(.), "oops"))
+    dx4 <- deferred$new(function(resolve) if (FALSE) resolve(TRUE) else stop("oops"))$
+      catch(error = function(.) expect_match(conditionMessage(.), "oops"))
 
     when_all(dx1, dx2, dx3, dx4)
   }
@@ -22,18 +22,18 @@ test_that("action in formula notation", {
 
 test_that("on_fulfilled / on_rejected without arguments", {
   do <- async(function() {
-    dx1 <- deferred$new(~resolve(TRUE))$
-      then(~ "OK")$
-      then(~ expect_equal(., "OK"))
+    dx1 <- deferred$new(function(resolve) resolve(TRUE))$
+      then(function() "OK")$
+      then(function(.) expect_equal(., "OK"))
 
-    dx2 <- deferred$new(~resolve(TRUE))$
-      then(~ stop("oops"))$
-      catch(error = ~ expect_match(conditionMessage(.), "oops"))
+    dx2 <- deferred$new(function(resolve) resolve(TRUE))$
+      then(function() stop("oops"))$
+      catch(error = function(.) expect_match(conditionMessage(.), "oops"))
 
-    dx3 <- deferred$new(~resolve(TRUE))$
-      then(~ stop("ooops"))$
-      catch(error = ~ "aaah")$
-      then(~ expect_equal(., "aaah"))
+    dx3 <- deferred$new(function(resolve) resolve(TRUE))$
+      then(function() stop("ooops"))$
+      catch(error = function(.) "aaah")$
+      then(function(.) expect_equal(., "aaah"))
 
     when_all(dx1, dx2, dx3)
   })
@@ -47,7 +47,7 @@ test_that("parent pointer", {
   do <- function() {
     d1 <- delay(1/1000)
     d2 <- d1$then(force)
-    d3 <- d2$then(~ expect_true(is.null(get_private(d2)$parent)))
+    d3 <- d2$then(function() expect_true(is.null(get_private(d2)$parent)))
     expect_equal(length(get_private(d2)$parent), 0)
     d3
   }
